import { jsx } from "react/jsx-runtime";
import { Component } from "react";
import { isHTMLElement } from "../lib/pdfjs-dom.js";
import styles from "../style/MouseSelection.module.css.js";
class MouseSelection extends Component {
  constructor() {
    super(...arguments);
    this.state = {
      locked: false,
      start: null,
      end: null
    };
    this.reset = () => {
      const { onDragEnd } = this.props;
      onDragEnd();
      this.setState({ start: null, end: null, locked: false });
    };
  }
  getBoundingRect(start, end) {
    return {
      left: Math.min(end.x, start.x),
      top: Math.min(end.y, start.y),
      width: Math.abs(end.x - start.x),
      height: Math.abs(end.y - start.y)
    };
  }
  componentDidUpdate() {
    const { onChange } = this.props;
    const { start, end } = this.state;
    const isVisible = Boolean(start && end);
    onChange(isVisible);
  }
  componentDidMount() {
    if (!this.root) {
      return;
    }
    const { onSelection, onDragStart, onDragEnd, shouldStart } = this.props;
    const container = this.root.parentElement;
    if (!container || !isHTMLElement(container)) {
      return;
    }
    let containerBoundingRect = null;
    const containerCoords = (pageX, pageY) => {
      if (!containerBoundingRect) {
        containerBoundingRect = container.getBoundingClientRect();
      }
      return {
        x: pageX - containerBoundingRect.left + container.scrollLeft,
        y: pageY - containerBoundingRect.top + container.scrollTop - window.scrollY
      };
    };
    container.addEventListener("mousemove", (event) => {
      const { start, locked } = this.state;
      if (!start || locked) {
        return;
      }
      this.setState({
        ...this.state,
        end: containerCoords(event.pageX, event.pageY)
      });
    });
    container.addEventListener("mousedown", (event) => {
      if (!shouldStart(event)) {
        this.reset();
        return;
      }
      const startTarget = event.target;
      if (!(startTarget instanceof Element) || !isHTMLElement(startTarget)) {
        return;
      }
      onDragStart();
      this.setState({
        start: containerCoords(event.pageX, event.pageY),
        end: null,
        locked: false
      });
      const onMouseUp = (event2) => {
        var _a;
        (_a = event2.currentTarget) == null ? void 0 : _a.removeEventListener(
          "mouseup",
          onMouseUp
        );
        const { start } = this.state;
        if (!start) {
          return;
        }
        const end = containerCoords(event2.pageX, event2.pageY);
        const boundingRect = this.getBoundingRect(start, end);
        if (!(event2.target instanceof Element) || !isHTMLElement(event2.target) || !container.contains(event2.target) || !this.shouldRender(boundingRect)) {
          this.reset();
          return;
        }
        this.setState(
          {
            end,
            locked: true
          },
          () => {
            const { start: start2, end: end2 } = this.state;
            if (!start2 || !end2) {
              return;
            }
            if (event2.target instanceof Element && isHTMLElement(event2.target)) {
              onSelection(startTarget, boundingRect, this.reset);
              onDragEnd();
            }
          }
        );
      };
      const { ownerDocument: doc } = container;
      if (doc.body) {
        doc.body.addEventListener("mouseup", onMouseUp);
      }
    });
  }
  shouldRender(boundingRect) {
    return boundingRect.width >= 1 && boundingRect.height >= 1;
  }
  render() {
    const { start, end } = this.state;
    return /* @__PURE__ */ jsx(
      "div",
      {
        ref: (node) => {
          if (!node) {
            return;
          }
          this.root = node;
        },
        children: start && end ? /* @__PURE__ */ jsx(
          "div",
          {
            className: styles.mouseSelection,
            style: this.getBoundingRect(start, end)
          }
        ) : null
      }
    );
  }
}
export {
  MouseSelection as default
};
